@@ -69,6 +69,16 @@ impl Response {
         })
     }
 
+    // Create a `Response` using a `ResponseBody` variant. Sets a status code of 200 and an empty
+    // set of Headers. Modify the Response with methods such as `with_status` and `with_headers`.
+    pub fn from_body(body: ResponseBody) -> Result<Self> {
+        Ok(Self {
+            body,
+            headers: Headers::new(),
+            status_code: 200,
+        })
+    }
+
     /// Create a `Response` using unprocessed text provided. Sets the associated `Content-Type`
     /// header for the `Response` as `text/plain`.
     pub fn ok(body: impl Into<String>) -> Result<Self> {
@@ -96,7 +106,7 @@ impl Response {
     pub fn error(msg: impl Into<String>, status: u16) -> Result<Self> {
         if !(400..=599).contains(&status) {
             return Err(Error::Internal(
-                "provided error status code is invalid".into(),
+                "error status codes must be in the 400-599 range! see https://developer.mozilla.org/en-US/docs/Web/HTTP/Status for more".into(),
             ));
         }
 
@@ -107,6 +117,27 @@ impl Response {
         })
     }
 
+    /// Create a `Response` which redirects to the specified URL with default status_code of 302
+    pub fn redirect(url: url::Url) -> Result<Self> {
+        match EdgeResponse::redirect(&url.as_str()) {
+            Ok(edge_response) => Ok(Response::from(edge_response)),
+            Err(err) => Err(Error::from(err)),
+        }
+    }
+
+    /// Create a `Response` which redirects to the specified URL with a custom status_code
+    pub fn redirect_with_status(url: url::Url, status_code: u16) -> Result<Self> {
+        if !(300..=399).contains(&status_code) {
+            return Err(Error::Internal(
+                "redirect status codes must be in the 300-399 range! Please checkout https://developer.mozilla.org/en-US/docs/Web/HTTP/Status#redirection_messages for more".into(),
+            ));
+        }
+        match EdgeResponse::redirect_with_status(&url.as_str(), status_code) {
+            Ok(edge_response) => Ok(Response::from(edge_response)),
+            Err(err) => Err(Error::from(err)),
+        }
+    }
+
     /// Get the HTTP Status code of this `Response`.
     pub fn status_code(&self) -> u16 {
         self.status_code
